@@ -29,6 +29,8 @@ import os
 
 from pyworkflow import VERSION_3_0
 
+from ..constants import CHIMERA_CONFIG_FILE
+
 try:
     from pwem.objects import AtomStruct
 except ImportError:
@@ -52,11 +54,14 @@ from pyworkflow.protocol.params import (MultiPointerParam,
 from pyworkflow.utils.properties import Message
 
 from .. import Plugin
-
+import configparser
 
 class ChimeraProtBase(EMProtocol):
     """Base class  for chimera protocol"""
     _version = VERSION_3_0
+    @classmethod
+    def getClassPackageName(cls):
+        return "chimerax"
 
     # --------------------------- DEFINE param functions --------------------
     def _defineParams(self, form, doHelp=True):
@@ -112,16 +117,6 @@ class ChimeraProtBase(EMProtocol):
         # building script file including the coordinate axes and the input
         # volume with samplingRate and Origin information
         f = open(self._getTmpPath(chimeraScriptFileName), "w")
-        f.write("from chimera import runCommand\n")
-
-        # create coherent header
-        createScriptFile(1,  # model id pdb
-                         1,  # model id 3D map
-                         self._getExtraPath(chimeraPdbTemplateFileName),
-                         self._getExtraPath(chimeraMapTemplateFileName),
-                         f,
-                         self._getExtraPath(sessionFile),
-                         )
 
         if self.inputVolume.get() is None:
             _inputVol = self.pdbFileToBeRefined.get().getVolume()
@@ -141,90 +136,160 @@ class ChimeraProtBase(EMProtocol):
         Chimera.createCoordinateAxisFile(dim,
                                          bildFileName=tmpFileName,
                                          sampling=sampling)
-        f.write("runCommand('open %s')\n" % tmpFileName)
-        f.write("runCommand('cofr 0,0,0')\n")  # set center of coordinates
+        f.write("open %s\n" % tmpFileName)
+        f.write("cofr 0,0,0\n")  # set center of coordinates
 
         # input vol with its origin coordinates
         pdbModelCounter = 1
         if _inputVol is not None:
+            pdbModelCounter += 1
             x_input, y_input, z_input = _inputVol.getShiftsFromOrigin()
             inputVolFileName = os.path.abspath(ImageHandler.removeFileType(
                 _inputVol.getFileName()))
-            f.write("runCommand('open %s')\n" % inputVolFileName)
-            f.write("runCommand('volume #%d style surface voxelSize %f')\n"
+            f.write("open %s\n" % inputVolFileName)
+            f.write("volume #%d style surface voxelSize %f\n"
                     % (pdbModelCounter, _inputVol.getSamplingRate()))
-            f.write("runCommand('volume #%d origin %0.2f,%0.2f,%0.2f')\n"
+            f.write("volume #%d origin %0.2f,%0.2f,%0.2f\n"
                     % (pdbModelCounter, x_input, y_input, z_input))
 
         if self.inputVolumes is not None:
-            if _inputVol is not None:
-                pdbModelCounter += 1
             for vol in self.inputVolumes:
-                f.write("runCommand('open %s')\n" % vol.get().getFileName())
-                x, y, z = vol.get().getShiftsFromOrigin()
-                f.write("runCommand('volume #%d style surface voxelSize %f')\n"
-                        % (pdbModelCounter, vol.get().getSamplingRate()))
-                f.write("runCommand('volume #%d origin %0.2f,%0.2f,%0.2f')\n"
-                        % (pdbModelCounter, x, y, z))
                 pdbModelCounter += 1
+                f.write("open %s\n" % os.path.abspath(vol.get().getFileName()))
+                x, y, z = vol.get().getShiftsFromOrigin()
+                f.write("volume #%d style surface voxelSize %f\n"
+                        % (pdbModelCounter, vol.get().getSamplingRate()))
+                f.write("volume #%d origin %0.2f,%0.2f,%0.2f\n"
+                        % (pdbModelCounter, x, y, z))
 
         if self.pdbFileToBeRefined.get() is not None:
+            pdbModelCounter += 1
             pdbFileToBeRefined = self.pdbFileToBeRefined.get()
-            f.write("runCommand('open %s')\n" % os.path.abspath(
+            f.write("open %s\n" % os.path.abspath(
                 pdbFileToBeRefined.getFileName()))
             if pdbFileToBeRefined.hasOrigin():
                 x, y, z = (pdbFileToBeRefined.getOrigin().getShifts())
-                f.write("runCommand('move %0.2f,%0.2f,%0.2f model #%d "
-                        "coord #0')\n" % (x, y, z, pdbModelCounter))
+                f.write("move %0.2f,%0.2f,%0.2f model #%d "
+                        "coord #0\n" % (x, y, z, pdbModelCounter))
 
         # Alignment of sequence and structure
-        if (hasattr(self, 'inputSequence') and
+        if (hasattr(self, 'inputSequence1') and
                 hasattr(self, 'inputStructureChain')):
-            if (self.inputSequence.get() is not None and
-                    self.inputStructureChain.get() is not None):
-                models = self.structureHandler.getModelsChains()
-                if len(models) > 1:
-                    f.write("runCommand('select #%d.%s:.%s')\n"
-                            % (pdbModelCounter, str(self.selectedModel),
-                               str(self.selectedChain)))
+            if (self.inputSequence1.get() is not None and
+                self.inputStructureChain.get() is not None):
+                pdbModelCounter = 2
+                if str(self.selectedModel) != '0':
+                    f.write("select #%s.%s/%s\n"
+                            % (pdbModelCounter,
+                               str(self.selectedModel + 1),
+                               str(self.selectedChain1)))
                 else:
-                    f.write("runCommand('select #%d:.%s')\n"
-                            % (pdbModelCounter, str(self.selectedChain)))
-                # f.write("runCommand('sequence selection')\n") # To open
-                # only the
-                # sequence of
-                # the selected
-                # chain
+                    f.write("select #%s/%s\n"
+                            % (pdbModelCounter,
+                               str(self.selectedChain1)))
+
                 if self._getOutFastaSequencesFile is not None:
-                    alignmentFile = self._getOutFastaSequencesFile()
-                    f.write("runCommand('open %s')\n" % alignmentFile)
+                    alignmentFile1 = self._getOutFastaSequencesFile(self.OUTFILE1)
+                    f.write("open %s\n" % alignmentFile1)
+                    f.write("sequence disassociate #%s %s\n" %
+                            (pdbModelCounter,
+                            alignmentFile1.split("/")[-1]))
+                    if str(self.selectedModel) != '0':
+                        f.write("sequence associate #%s.%s/%s %s:1\n" %
+                                (pdbModelCounter,
+                                 str(self.selectedModel + 1),
+                                 str(self.selectedChain1),
+                                 alignmentFile1.split("/")[-1]))
+                    else:
+                        f.write("sequence associate #%s/%s %s:1\n" %
+                                (pdbModelCounter,
+                                 str(self.selectedChain1),
+                                 alignmentFile1.split("/")[-1]))
+
+            if (self.additionalTargetSequence.get() is True and
+                self.inputSequence2.get() is not None and
+                self.inputStructureChain.get() is not None):
+                f.write("select clear\n")
+                f.write("select #%s/%s,%s\n"
+                        % (pdbModelCounter,
+                           str(self.selectedChain1),
+                           str(self.selectedChain2)))
+
+                if self._getOutFastaSequencesFile is not None:
+                    alignmentFile2 = self._getOutFastaSequencesFile(self.OUTFILE2)
+                    f.write("open %s\n" % alignmentFile2)
+                    f.write("sequence disassociate #%s %s\n" %
+                            (pdbModelCounter,
+                            alignmentFile2.split("/")[-1]))
+                    if str(self.selectedModel) != '0':
+                        f.write("sequence associate #%s.%s/%s %s:1\n" %
+                                (pdbModelCounter,
+                                 str(self.selectedModel + 1),
+                                 str(self.selectedChain2),
+                                 alignmentFile2.split("/")[-1]))
+                    else:
+                        f.write("sequence associate #%s/%s %s:1\n" %
+                                (pdbModelCounter,
+                                 str(self.selectedChain2),
+                                 alignmentFile2.split("/")[-1]))
 
         # other pdb files
-        pdbModelCounter += 1
         for pdb in self.inputPdbFiles:
-            f.write("runCommand('open %s')\n" % os.path.abspath(pdb.get(
+            pdbModelCounter += 1
+            f.write("open %s\n" % os.path.abspath(pdb.get(
             ).getFileName()))
             if pdb.get().hasOrigin():
                 x, y, z = pdb.get().getOrigin().getShifts()
-                f.write("runCommand('move %0.2f,%0.2f,%0.2f model #%d "
-                        "coord #0')\n" % (x, y, z, pdbModelCounter))
+                f.write("move %0.2f,%0.2f,%0.2f model #%d "
+                        "coord #0\n" % (x, y, z, pdbModelCounter))
             # TODO: Check this this this this this this
-            pdbModelCounter += 1
+
+        # Go to extra dir and save there the output of
+        # scipionwrite
+        #f.write('cd %s' % os.path.abspath(
+        #    self._getExtraPath()))
+        # save config file with information
+        # this is information is pased from scipion to chimerax
+        config = configparser.ConfigParser()
+        _chimeraPdbTemplateFileName = \
+            os.path.abspath(self._getExtraPath(
+                chimeraPdbTemplateFileName))
+        _chimeraMapTemplateFileName = \
+            os.path.abspath(self._getExtraPath(
+                chimeraMapTemplateFileName))
+        _sessionFile = os.path.abspath(
+            self._getExtraPath(sessionFile))
+        protId = self.getObjId()
+        config['chimerax'] = {'chimerapdbtemplatefilename':
+                                  _chimeraPdbTemplateFileName % protId,
+                              'chimeramaptemplatefilename':
+                                  _chimeraMapTemplateFileName % protId,
+                              'sessionfile': _sessionFile,
+                              'enablebundle': True,
+                              'protid': self.getObjId()}
+                              # set to True when
+                              # protocol finished
+                              # viewers will check this configuration file
+        with open(self._getExtraPath(CHIMERA_CONFIG_FILE),
+                  'w') as configfile:
+            config.write(configfile)
 
         # run the text:
+        _chimeraScriptFileName = os.path.abspath(
+            self._getTmpPath(chimeraScriptFileName))
         if len(self.extraCommands.get()) > 2:
             f.write(self.extraCommands.get())
-            args = " --nogui --script " + self._getTmpPath(
-                chimeraScriptFileName)
+            args = " --nogui " + _chimeraScriptFileName
         else:
-            args = " --script " + self._getTmpPath(chimeraScriptFileName)
+            args = " " + _chimeraScriptFileName
 
         f.close()
 
         self._log.info('Launching: ' + Plugin.getProgram() + ' ' + args)
 
         # run in the background
-        Chimera.runProgram(Plugin.getProgram(), args)
+        cwd = os.path.abspath(self._getExtraPath())
+        Chimera.runProgram(Plugin.getProgram(), args, cwd=cwd)
 
     def createOutput(self):
         """ Copy the PDB structure and register the output object.
@@ -253,11 +318,20 @@ class ChimeraProtBase(EMProtocol):
                 path = os.path.join(directory, filename)
                 pdb = AtomStruct()
                 pdb.setFileName(path)
-                keyword = filename.split(".pdb")[0].replace(".","_")
+                if filename.endswith(".cif"):
+                    keyword = filename.split(".cif")[0].replace(".","_")
+                else:
+                    keyword = filename.split(".pdb")[0].replace(".", "_")
                 kwargs = {keyword: pdb}
                 self._defineOutputs(**kwargs)
-
-
+        # upodate config file flag enablebundle
+        # so scipionwrite is disabled
+        config = configparser.ConfigParser()
+        config.read(self._getExtraPath(CHIMERA_CONFIG_FILE))
+        config.set('chimerax', 'enablebundle', 'False')
+        with open(self._getExtraPath(CHIMERA_CONFIG_FILE),
+                  'w') as configfile:
+            config.write(configfile)
     # --------------------------- INFO functions ----------------------------
     def _validate(self):
         errors = []
@@ -275,7 +349,7 @@ class ChimeraProtBase(EMProtocol):
             errors.append("and set CHIMERA_HOME variables properly.")
             if program is not None:
                 errors.append("Current value:")
-                errors.append("CHIMERA_HOME = %s" % os.environ['CHIMERA_HOME'])
+                errors.append("CHIMERA_HOME = %s" % Plugin.getHome())
 
         return errors
 
@@ -304,7 +378,7 @@ class ChimeraProtBase(EMProtocol):
         return methodsMsgs
 
     def _citations(self):
-        return ['Pettersen2004']
+        return ['Goddard2018']
 
     def is_tool(self, name):
         """Check whether `name` is on PATH."""
@@ -312,6 +386,10 @@ class ChimeraProtBase(EMProtocol):
         return find_executable(name) is not None
 
 
+# TODO: all lines below ths pint should
+# be deleted, please delete them after protocol_substraction_maps
+# is updated
+
 # define scipion_write command
 chimeraScriptHeader = '''
 import os
